﻿<# 
.Synopsis
   Get list from folder in vCenter, produce report of violations to the rules.
.Description
   Connects to vCenter using previously written Connect-vCenter.ps1 and requests Folder to scan 
   Synchronously gets VMs and connects to each one prompting for disk size, and if the NTPSync Service is running.  
   Reports on deviations and starts service if stopped.	
.Input
   Credentials through Connect-vCenter.ps1 switch
	vCenter Name
	vCenter folder name
	Email account to send report
.Output
   Report
.Author
   Chris Halverson
.Change Log
   12/16/2015
.FileName
   Report-AppSettings.ps1
.Version
    Draft 0.1
#>
### Add argument for BatchMode –b that will pull data from a file.
$SVC = "DFS"
#Invoke connect-vCenter.ps1
Invoke-Expression -command .\Connect-vCenter.ps1

<#
To get the folder to be selected the script will use a selection mechanism that shows the available Datacenters first.  Once the Datacenter is selected, then the folders can be shown and selected. 
#> 
$DC = Get-DataCenter
Switch ($DC.Count)
    {
	"0" {
        Write-host -ForegroundColor Red 'No available Datacenters exist! Exiting'
		Exit
        }
	"1" {$DCSel = $DC}
	default {
		Write-Host "`n"
		$menu = @{}
		for ($i=1;$i -le $DC.count; $i++) 
            {
    		Write-Host "$i. $($DC[$i-1])"
    		$menu.Add($i,($DC[$i-1]))
    		}
		Write-Host "`n"
		[console]::ForegroundColor = "Yellow"
		[int]$ans = Read-Host 'Choose the Datacenter '
		[console]::ForegroundColor = "Gray"
		$DCSel = $menu.item($ans)
		}
	}
$Menu = $Null
$Ans = $Null

$Folder = Get-DataCenter | Where Name –match $DCSel | Get-Folder -type VM | Where Name -NotMatch "vm" 
Write-Host “`n”
$Menu = @{}
for ($i=1;$i –le $Folder.Count;$i++)
    {
	Write-Host “$i. $($Folder[$i-1])”
	$Menu.Add($i,($Folder[$i-1]))
	}
Write-Host “`n”
[console]::ForegroundColor = “Yellow”
[int]$Ans = Read-Host ‘Choose the Folder to Validate against ‘
Write-Host "`n"
[console]::ForegroundColor = “Gray”
$FolderSel = $Menu.item($Ans)

<# 
Folder is selected, setting a pre-determined datastore for the VMs to be placed in.
#>
$DataStore = Get-DataStore SYN-iSCSI-SSD

## Pull VM data from the selected folder.

$VMs = Get-Folder –Name $FolderSel | Get-VM
#$cnt = $VMs.Count

Write-Host -foregroundColor Cyan "Confirmed VM count is $($VMs.Count), beginning parsing data"

## Begin Loop per VM

Foreach ($VM in $VMs) 
    {
	Write-Host "`nScanning $VM "
	Write-Host -foregroundcolor Green "Testing the Power state of the VM"
    If ($VM.PowerState -match "Off") {
        Write-Host -foregroundcolor Red "Machine not Powered On, bypassing VM"
        }
    Else {
        Write-Host –ForegroundColor Yellow ‘Examining Datastore Location’
	    Write-Host "The DataStore - $($VM | Get-Datastore) - is currently being used"
        If ($($VM | Get-Datastore) –ne $DataStore)
            {
            $VM | Move-VM –Datastore $DataStore –Confirm:$False | out-null
            }
        $view = $VM | Get-View 

    ##Verify the DNS name from VMtools
    
        $VMName = $View.Summary.Guest.HostName
        Write-Host –ForegroundColor Green "`tGetting DNS Name ... $($VMName)"
    ##Test Connectivity to the VM through IP connectivity

        If (Test-Connection -ComputerName $VMName -Count 2)
            {
        ##Launch Remote PowerShell Session
            $PS = New-PSSession –Computername $VMName –Credential $Cred
        ##Check the DiskStatus
            $DiskOut = Invoke-Command –Session $PS –ScriptBlock ` {[System.Math]::Round((Get-PsDrive –Name C | % Free)/1GB, 2)}
            Write-Host -foregroundcolor Yellow "`tDisk Size of GuestOS is $DiskOut GB"
        ##Check the Service Status
            $SvcStatus = Invoke-Command –Session $PS –ScriptBlock {
                Get-Service | ? Name –match $SVC
                }
            Enter-PSSession $PS 
            ##Has to redefine the SVC variable due to this running inside the PSsession
            $SVC = "DFS"
            If ($(Get-Service | ? Name –match $SVC).Status –ne “Running”)
                {
                Start-Service –name $SVC –erroraction SilentlyContinue
                }
            Exit-PSSession
            $SvcStatus = Invoke-Command –Session $PS –ScriptBlock {
                Get-Service 
                } 
            $SvcStatus | ? Name –eq $SVC | FT -HideTableHeaders
            }
        }
    }

	

